@@ -1,7 +1,12 @@
-import hashlib, binascii, os
+import hashlib
+import binascii
+import os
+
 
 def salted_sha512_hash_password(password):
     salt = hashlib.sha256(os.urandom(60)).hexdigest().encode('ascii')
-    pwdhash = hashlib.pbkdf2_hmac('sha512', password.encode('utf-8'), salt, 100000)
+    pwdhash = hashlib.pbkdf2_hmac(
+        'sha512', password.encode('utf-8'), salt, 100000
+    )
     pwdhash = binascii.hexlify(pwdhash)
-    return (salt + pwdhash).decode('ascii')
\ No newline at end of file
+    return (salt + pwdhash).decode('ascii')
